 .. _development:

DIPY Developer Guide
====================

.. toctree::
   :maxdepth: 2

   intro
   installing_from_source
   gitwash/index
   make_release
   commit_codes
   coding_style_guideline
   benchmarking
   toolchain

